---
title: Partition
---

!!! warning
    This class is superseded by [pyslurm.Partition](../partition.md) and will
    be removed in a future release.

::: pyslurm.deprecated.partition
    handler: python
